@@ -39,7 +39,7 @@ enum CE_Options {
 
 static bool readConfigForCEOption(CE_Options o)
 {
-    KConfigGroup cg(KSharedConfig::openConfig(), "kate_compilerexplorer");
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("kate_compilerexplorer"));
     switch (o) {
     case CE_Option_FilterLabel:
         return cg.readEntry("FilterUnusedLabels", true);
@@ -58,7 +58,7 @@ static bool readConfigForCEOption(CE_Options o)
 
 static void writeConfigForCEOption(CE_Options o, bool value)
 {
-    KConfigGroup cg(KSharedConfig::openConfig(), "kate_compilerexplorer");
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("kate_compilerexplorer"));
     switch (o) {
     case CE_Option_FilterLabel:
         return cg.writeEntry("FilterUnusedLabels", value);
@@ -123,20 +123,8 @@ CEWidget::~CEWidget()
 bool CEWidget::shouldClose()
 {
     int ret =
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
-        KMessageBox::warningTwoActions(this,
-#else
-        KMessageBox::warningYesNo(this,
-#endif
-                                       i18n("Do you really want to close %1?", windowTitle()),
-                                       {},
-                                       KStandardGuiItem::close(),
-                                       KStandardGuiItem::cancel());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        KMessageBox::warningTwoActions(this, i18n("Do you really want to close %1?", windowTitle()), {}, KStandardGuiItem::close(), KStandardGuiItem::cancel());
     return ret == KMessageBox::PrimaryAction;
-#else
-    return ret == KMessageBox::Yes;
-#endif
 }
 
 void CEWidget::removeViewAsActiveXMLGuiClient()
@@ -169,7 +157,7 @@ bool CEWidget::eventFilter(QObject *o, QEvent *e)
     }
 
     auto event = static_cast<QHoverEvent *>(e);
-    auto cursor = m_textEditor->coordinatesToCursor(event->pos());
+    auto cursor = m_textEditor->coordinatesToCursor(event->position().toPoint());
     Q_EMIT lineHovered(cursor.line()); // Can be invalid, that is okay
     m_asmView->viewport()->update();
 
@@ -316,7 +304,7 @@ void CEWidget::initOptionsComboBox()
     menu->addAction(checkableAction(i18n("Intel Syntax"), CE_Option_IntelAsm));
 
     menu->addAction(i18n("Change Url..."), this, [this] {
-        KConfigGroup cg(KSharedConfig::openConfig(), "kate_compilerexplorer");
+        KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("kate_compilerexplorer"));
         QString url = cg.readEntry("kate_compilerexplorer_url", QStringLiteral("http://localhost:10240"));
 
         bool ok = false;
