@@ -18,7 +18,7 @@
 
 K_PLUGIN_FACTORY_WITH_JSON(KateSnippetsPluginFactory, "katesnippetsplugin.json", registerPlugin<KateSnippetsPlugin>();)
 
-KateSnippetsPlugin::KateSnippetsPlugin(QObject *parent, const QList<QVariant> &)
+KateSnippetsPlugin::KateSnippetsPlugin(QObject *parent, const QVariantList &)
     : KTextEditor::Plugin(parent)
     , m_snippetGlobal(new KateSnippetGlobal(this))
 {
