@@ -239,57 +239,9 @@ int main(int argc, char **argv)
         /**
          * try to get the current running kate instances
          */
-        KateRunningInstanceMap mapSessionRii;
-        if (!fillinRunningKateAppInstances(&mapSessionRii)) {
-            return 1;
-        }
-
-        QString currentActivity;
-        QDBusMessage m = QDBusMessage::createMethodCall(QStringLiteral("org.kde.ActivityManager"),
-                                                        QStringLiteral("/ActivityManager/Activities"),
-                                                        QStringLiteral("org.kde.ActivityManager.Activities"),
-                                                        QStringLiteral("CurrentActivity"));
-        QDBusMessage res = QDBusConnection::sessionBus().call(m);
-        QVariantList answer = res.arguments();
-        if (answer.size() == 1) {
-            currentActivity = answer.at(0).toString();
-        }
-
-        QStringList kateServices;
-        for (const auto &[_, katerunninginstanceinfo] : mapSessionRii) {
-            Q_UNUSED(_)
-            QString serviceName = katerunninginstanceinfo.serviceName;
-
-            if (currentActivity.length() != 0) {
-                QDBusMessage m = QDBusMessage::createMethodCall(serviceName,
-                                                                QStringLiteral("/MainApplication"),
-                                                                QStringLiteral("org.kde.Kate.Application"),
-                                                                QStringLiteral("isOnActivity"));
-
-                QVariantList dbargs;
-
-                // convert to an url
-                dbargs.append(currentActivity);
-                m.setArguments(dbargs);
-
-                QDBusMessage res = QDBusConnection::sessionBus().call(m);
-                QVariantList answer = res.arguments();
-                if (answer.size() == 1) {
-                    const bool canBeUsed = answer.at(0).toBool();
-
-                    // If the Kate instance is in a specific activity, add it to
-                    // the list of candidate reusable services
-                    if (canBeUsed) {
-                        kateServices << serviceName;
-                    }
-                }
-            } else {
-                kateServices << serviceName;
-            }
-        }
+        const auto kateServices = fillinRunningKateAppInstances();
 
         QString serviceName;
-
         QString start_session;
         bool session_already_opened = false;
 
@@ -298,9 +250,11 @@ int main(int argc, char **argv)
             force_new = true;
         } else if (parser.isSet(startSessionOption)) {
             start_session = parser.value(startSessionOption);
-            auto it = mapSessionRii.find(start_session);
-            if (it != mapSessionRii.end()) {
-                serviceName = it->second.serviceName;
+            const auto it = std::find_if(kateServices.cbegin(), kateServices.cend(), [&start_session](const auto &instance) {
+                return instance.sessionName == start_session;
+            });
+            if (it != kateServices.end()) {
+                serviceName = it->serviceName;
                 force_new = false;
                 session_already_opened = true;
             }
@@ -314,49 +268,24 @@ int main(int argc, char **argv)
                 QString usePid = (parser.isSet(usePidOption)) ? parser.value(usePidOption) : QString::fromLocal8Bit(qgetenv("KATE_PID"));
 
                 serviceName = QLatin1String("org.kde.kate-") + usePid;
-                if (!kateServices.contains(serviceName)) {
+                const auto it = std::find_if(kateServices.cbegin(), kateServices.cend(), [&serviceName](const auto &instance) {
+                    return instance.serviceName == serviceName;
+                });
+                if (it == kateServices.end()) {
                     serviceName.clear();
                 }
             }
         }
 
-        // prefer the Kate instance running on the current virtual desktop
+        // prefer the Kate instance that got activated last
         bool foundRunningService = false;
-        if ((!force_new) && (serviceName.isEmpty())) {
-            int desktopnumber = 0;
-#if HAVE_X11
-            if (KWindowSystem::isPlatformX11()) {
-                desktopnumber = KX11Extras::currentDesktop();
-            }
-#endif
-
-            for (int s = 0; s < kateServices.count(); s++) {
-                serviceName = kateServices[s];
-
-                if (!serviceName.isEmpty()) {
-                    QDBusReply<bool> there = sessionBusInterface->isServiceRegistered(serviceName);
-
-                    if (there.isValid() && there.value()) {
-                        // query instance current desktop
-                        QDBusMessage m = QDBusMessage::createMethodCall(serviceName,
-                                                                        QStringLiteral("/MainApplication"),
-                                                                        QStringLiteral("org.kde.Kate.Application"),
-                                                                        QStringLiteral("desktopNumber"));
-
-                        QDBusMessage res = QDBusConnection::sessionBus().call(m);
-                        QVariantList answer = res.arguments();
-                        if (answer.size() == 1) {
-                            // special case: on all desktops! that is -1 aka NET::OnAllDesktops, see KWindowInfo::desktop() docs
-                            const int sessionDesktopNumber = answer.at(0).toInt();
-                            if (sessionDesktopNumber == desktopnumber || sessionDesktopNumber == -1) {
-                                // stop searching. a candidate instance in the current desktop has been found
-                                foundRunningService = true;
-                                break;
-                            }
-                        }
-                    }
+        if (!force_new && serviceName.isEmpty()) {
+            qint64 lastUsedChosen = 0;
+            for (const auto &currentService : kateServices) {
+                if (currentService.lastActivationChange > lastUsedChosen) {
+                    serviceName = currentService.serviceName;
+                    lastUsedChosen = currentService.lastActivationChange;
                 }
-                serviceName.clear();
             }
         }
 
