@@ -5,6 +5,7 @@
 
 #include "kateurlbar.h"
 #include "kateapp.h"
+#include "katemainwindow.h"
 #include "kateviewmanager.h"
 #include "ktexteditor_utils.h"
 
@@ -253,9 +254,9 @@ public:
         const auto fileInfos = dir.entryInfoList(QDir::NoDotAndDotDot | QDir::Files | QDir::Dirs | QDir::Hidden);
         for (const auto &fi : fileInfos) {
             if (fi.isDir()) {
-                m_fileInfos << fi;
+                m_fileInfos.push_back(fi);
             } else if (QMimeDatabase().mimeTypeForFile(fi).inherits(QStringLiteral("text/plain"))) {
-                m_fileInfos << fi;
+                m_fileInfos.push_back(fi);
             }
         }
         endResetModel();
@@ -267,7 +268,7 @@ public:
     }
 
 private:
-    QList<QFileInfo> m_fileInfos;
+    std::vector<QFileInfo> m_fileInfos;
     QDir m_currentDir;
 };
 
@@ -604,7 +605,7 @@ public:
     {
         auto pal = palette();
         pal.setBrush(QPalette::Base, qobject_cast<QWidget *>(parent())->palette().window());
-        auto textColor = pal.text().color();
+        auto textColor = pal.windowText().color();
         textColor = textColor.lightness() > 127 ? textColor.darker(150) : textColor.lighter(150);
         pal.setBrush(QPalette::Inactive, QPalette::Text, textColor);
         pal.setBrush(QPalette::Active, QPalette::Text, textColor);
@@ -623,7 +624,7 @@ public:
         m_model.clear();
         m_symbolsModel = nullptr;
 
-        int i = 0;
+        size_t i = 0;
         QIcon seperator = m_urlBar->seperator();
         for (const auto &dir : dirs) {
             auto item = new QStandardItem(dir.name);
@@ -929,15 +930,15 @@ private:
         }
     }
 
-    static QList<DirNamePath> splittedUrl(const QString &base, const QString &s)
+    static std::vector<DirNamePath> splittedUrl(const QString &base, const QString &s)
     {
         QDir dir(s);
         const QString fileName = dir.dirName();
         dir.cdUp();
         const QString path = dir.absolutePath();
 
-        QList<DirNamePath> dirsList;
-        dirsList << DirNamePath{fileName, path};
+        std::vector<DirNamePath> dirsList;
+        dirsList.push_back(DirNamePath{fileName, path});
 
         // arrived at base?
         if (dir.absolutePath() == base) {
