@@ -2,8 +2,7 @@
     SPDX-FileCopyrightText: 2022 Waqar Ahmed <waqar.17a@gmail.com>
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef KATE_URL_BAR_H
-#define KATE_URL_BAR_H
+#pragma once
 
 #include "kateviewspace.h"
 
@@ -38,5 +37,3 @@ private:
 Q_SIGNALS:
     void openUrlRequested(const QUrl &url, Qt::KeyboardModifiers);
 };
-
-#endif
